@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.15 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: amenu.h,v 1.17 2009/01/04 00:24:51 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -119,6 +119,12 @@ typedef enum {
 	/* ƱʪäƤ */
 	AUTO_MARK_COND_OWN,
 
+	/* ̺ */
+	AUTO_MARK_COND_IDENTIFIED,
+
+	/* ̤ */
+	AUTO_MARK_COND_UN_IDENTIFIED,
+
 	/* 1  HP ξʤ */
 	AUTO_MARK_COND_HP_MIN,
 
