@@ -5,10 +5,12 @@ extern "C" {
 #endif
 
 void	init_fx( void );
+void	reset_static_fx( void );
 void	inc_turn_all_fx( void );
 void	inc_day_all_fx( void );
 void	natural_cure_hp_chr( chr_t *chr );
 void	natural_cure_mp_chr( chr_t *chr );
+void	natural_cure_exp_chr( chr_t *chr );
 void	modifier_cure_hp_chr( chr_t *chr );
 void	modifier_cure_mp_chr( chr_t *chr );
 void	sober( chr_t *chr );
@@ -167,6 +169,8 @@ bool_t	fx_cure_hp_moderate( chr_t *chr, long lev );
 bool_t	fx_cure_hp_serious( chr_t *chr, long lev );
 bool_t	fx_cure_hp_max( chr_t *chr, long lev );
 bool_t	fx_cure_hp( chr_t *chr, long lev, rate_t rate );
+bool_t	fx_cure_mp_max( chr_t *chr, long lev );
+bool_t	fx_cure_mp( chr_t *chr, long lev, rate_t rate );
 bool_t	fx_transfer_mp( chr_t *chr, spell_tab_t *tab, rate_t rate );
 bool_t	fx_cure_lev( chr_t *chr );
 bool_t	fx_cure_exp_party( void );
@@ -202,6 +206,56 @@ bool_t	pow_up_armor_ac( item_t *armor );
 bool_t	protect_armor( item_t *armor );
 void	fx_cast_spell( chr_t *chr, spell_tab_t *tab );
 void	fx_word_of_destruction( chr_t *chr, spell_tab_t *tab );
+bool_t	rub_lamp( chr_t *chr, item_t *item );
+bool_t	fx_wish( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_chk_price(
+	chr_t *chr,
+	wish_level_t wish_level,
+	wish_kind_t kind
+);
+bool_t	fx_wish_exec(
+	chr_t *chr,
+	wish_level_t wish_level,
+	wish_kind_t kind
+);
+bool_t	fx_wish_pay_price(
+	chr_t *chr,
+	wish_level_t wish_level,
+	wish_kind_t kind
+);
+bool_t	chk_wish_price_exp( chr_t *chr, wish_kind_t kind );
+bool_t	chk_wish_price_gold( chr_t *chr, wish_kind_t kind );
+bool_t	chk_wish_price_contribution( chr_t *chr, wish_kind_t kind );
+void	pay_wish_price_exp( chr_t *chr, wish_kind_t kind );
+void	pay_wish_price_gold( chr_t *chr, wish_kind_t kind );
+void	pay_wish_price_contribution( chr_t *chr, wish_kind_t kind );
+long	calc_wish_price_exp( chr_t *chr, wish_kind_t kind );
+gold_t	calc_wish_price_gold( chr_t *chr, wish_kind_t kind );
+gold_t	calc_wish_price_contribution( chr_t *chr, wish_kind_t kind );
+wish_kind_t	exec_menu_wish( mbr_t *mbr, wish_level_t wish_level );
+char	*cb_menu_sel_wish( menu_t **pp, menu_t **dflt );
+bool_t	fx_wish_armageddon( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_cure_hp( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_cure_mp( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_resurrection( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_artifact( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wpn_randm_art_drain(
+	char mnr,
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_hp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_mp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_exp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
 bool_t	eat_food( chr_t *chr, item_t *item );
 bool_t	chk_mnstr_catch_food( chr_t *chr, item_t *item );
 bool_t	fx_mnstr_catch_food( chr_t *chr, item_t *item );
@@ -230,6 +284,8 @@ void	inc_chr_caught( chr_t *chr, long n );
 blast_t	*get_blast_spell( spell_kind_t kind );
 blast_t	*get_blast( blast_kind_t kind );
 void	set_blast_size( blast_t *p );
+flg_stat_t	cv_fx_kind_to_flg_stat( fx_kind_t fx_kind );
+resi_kind_t	cv_fx_kind_to_resi_kind( fx_kind_t fx_kind );
 void	lost_fx_chr( chr_t *chr );
 void	lost_fx_chr_sub( chr_t *chr, fx_t *fx );
 fx_t	*asgn_fx( fx_t *p );
