@@ -51,6 +51,9 @@ sub_race_t	trans_idx_to_sub_race_kind( long idx );
 long	trans_sub_race_kind_to_idx( sub_race_t k );
 sex_t	trans_idx_to_sex_kind( long idx );
 long	trans_sex_kind_to_idx( sex_t k );
+long	get_abl_kind_trans_tab_max_n( void );
+abl_kind_t	trans_idx_to_abl_kind( long idx );
+long	trans_abl_kind_to_idx( abl_kind_t k );
 move_kind_t	trans_idx_to_move_kind( long idx );
 long	trans_move_kind_to_idx( move_kind_t k );
 long	get_move_ls_trans_tab_max_n( void );
@@ -74,12 +77,18 @@ attitude_t	trans_idx_to_attitude_kind( long idx );
 long	trans_attitude_kind_to_idx( attitude_t k );
 item_kind_t	trans_idx_to_item_kind( long idx );
 long	trans_item_kind_to_idx( item_kind_t k );
+star_drop_kind_t	trans_idx_to_key_item_kind( long idx );
+long	trans_key_item_kind_to_idx( star_drop_kind_t k );
 wpn_kind_t	trans_idx_to_wpn_kind( long idx );
 long	trans_wpn_kind_to_idx( wpn_kind_t k );
 bow_kind_t	trans_idx_to_bow_kind( long idx );
 long	trans_bow_kind_to_idx( bow_kind_t k );
 armor_kind_t	trans_idx_to_armor_kind( long idx );
 long	trans_armor_kind_to_idx( armor_kind_t k );
+wpn_randm_art_kind_t	trans_idx_to_wpn_randm_art_kind( long idx );
+long	trans_wpn_randm_art_kind_to_idx( wpn_randm_art_kind_t k );
+armor_randm_art_kind_t	trans_idx_to_armor_randm_art_kind( long idx );
+long	trans_armor_randm_art_kind_to_idx( armor_randm_art_kind_t k );
 long	get_potion_trans_tab_max_n( void );
 potion_kind_t	trans_idx_to_potion_kind( long idx );
 long	trans_potion_kind_to_idx( potion_kind_t k );
@@ -194,6 +203,8 @@ bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
+bool_t	load_game_conf_gnome( char *id, long val );
+bool_t	load_game_conf_set_window_position( char *id, long val );
 bool_t	load_game_conf_win_pos( char *id, long val, win_kind_t kind );
 bool_t	load_game_conf_vfx_mbr( flg_vfx_mbr_t flg, long val );
 bool_t	load_game_conf_vfx_mnstr( flg_vfx_mnstr_t flg, long val );
@@ -238,6 +249,8 @@ bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_screen_size( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
@@ -522,6 +535,9 @@ bool_t	load_game_data_item_junk_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	mbr_t *mbr, item_t *item
 );
+bool_t	load_game_data_key_item_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	load_game_data_auto_mark_ls_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long ls_mbr_n
@@ -707,6 +723,9 @@ bool_t	save_game_data_potion_identified_ver_1(
 bool_t	save_game_data_scroll_identified_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_key_item_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_auto_mark_ls_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
