@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.200 2008/09/07 11:31:27 bowkenken Exp $
+* $Id: gfile.c,v 1.207 2009/05/20 02:50:03 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -47,6 +47,8 @@ void	init_game_file( void )
 {
 	char	*home, *s;
 
+	g_rc_lex_num_mode = 0;
+
 	g_game_data_save_n = 0;
 	g_randm_seed_save = get_randm_seed();
 
@@ -631,19 +633,37 @@ rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 		case '\"':
 			return( rc_lex_str( fp, u, flg_err_exit ) );
 		case '0':
-			c = rc_lex_getc( fp, TRUE, flg_err_exit );
-			if( ('0' <= c) && (c <= '7') ){
+			if( g_rc_lex_num_mode == 8 ){
 				rc_lex_ungetc( fp, c );
 				n = rc_lex_oct( fp,
 						TOKEN_MAX_LEN,
 						flg_err_exit );
-			} else if( (c == 'x') || (c == 'X') ){
+			} else if( g_rc_lex_num_mode == 10 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else if( g_rc_lex_num_mode == 16 ){
+				rc_lex_ungetc( fp, c );
 				n = rc_lex_hex_dec( fp,
 						TOKEN_MAX_LEN,
 						flg_err_exit );
 			} else {
-				rc_lex_ungetc( fp, c );
-				n = 0;
+				c = rc_lex_getc( fp, TRUE, flg_err_exit );
+
+				if( ('0' <= c) && (c <= '7') ){
+					rc_lex_ungetc( fp, c );
+					n = rc_lex_oct( fp,
+							TOKEN_MAX_LEN,
+							flg_err_exit );
+				} else if( (c == 'x') || (c == 'X') ){
+					n = rc_lex_hex_dec( fp,
+							TOKEN_MAX_LEN,
+							flg_err_exit );
+				} else {
+					rc_lex_ungetc( fp, c );
+					n = 0;
+				}
 			}
 
 			if( u != NULL )
@@ -658,10 +678,22 @@ rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 		case '7':
 		case '8':
 		case '9':
-			rc_lex_ungetc( fp, c );
-			n = rc_lex_dec( fp,
-					TOKEN_MAX_LEN,
-					flg_err_exit );
+			if( g_rc_lex_num_mode == 8 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_oct( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else if( g_rc_lex_num_mode == 16 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_hex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else {
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			}
 
 			if( u != NULL )
 				u->n = n;
@@ -1190,6 +1222,63 @@ long	trans_sex_kind_to_idx( sex_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥåǽͤؤѴơ֥ǿ֤
+* return : ǿ
+***************************************************************/
+
+long	get_abl_kind_trans_tab_max_n( void )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_abl_trans_tab );
+	max_idx /= sizeof( g_abl_trans_tab[0] );
+
+	return max_idx;
+}
+
+/***************************************************************
+* ǥåǽͤѴ
+* long idx : ǥå
+* return : ǽ
+***************************************************************/
+
+abl_kind_t	trans_idx_to_abl_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_abl_trans_tab )
+			/ sizeof( g_abl_trans_tab[0] );
+
+	if( idx < 0 )
+		return( (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_NULL) );
+	if( idx >= max_idx )
+		return( (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_NULL) );
+
+	return( g_abl_trans_tab[idx] );
+}
+
+/***************************************************************
+* ǽͤ饤ǥåѴ
+* abl_kind_t k : ǽ
+* return : ǥå
+***************************************************************/
+
+long	trans_abl_kind_to_idx( abl_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_abl_trans_tab )
+			/ sizeof( g_abl_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_abl_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥå⤭μѴ
 * long idx : ǥå
@@ -1667,6 +1756,48 @@ long	trans_item_kind_to_idx( item_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥå饭ƥμѴ
+* long idx : ǥå
+* return : ƥμ
+***************************************************************/
+
+star_drop_kind_t	trans_idx_to_key_item_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_key_item_trans_tab )
+			/ sizeof( g_key_item_trans_tab[0] );
+
+	if( idx < 0 )
+		return STAR_DROP_KIND_ELEC;
+	if( idx >= max_idx )
+		return STAR_DROP_KIND_ELEC;
+
+	return( g_key_item_trans_tab[idx] );
+}
+
+/***************************************************************
+* ƥμफ饤ǥåѴ
+* star_drop_kind_t k : ƥμ
+* return : ǥå
+***************************************************************/
+
+long	trans_key_item_kind_to_idx( star_drop_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_key_item_trans_tab )
+			/ sizeof( g_key_item_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_key_item_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥåμѴ
 * long idx : ǥå
@@ -1793,6 +1924,90 @@ long	trans_armor_kind_to_idx( armor_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥå RAF μѴ
+* long idx : ǥå
+* return : ɶμ
+***************************************************************/
+
+wpn_randm_art_kind_t	trans_idx_to_wpn_randm_art_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_wpn_randm_art_trans_tab )
+			/ sizeof( g_wpn_randm_art_trans_tab[0] );
+
+	if( idx < 0 )
+		return WPN_RANDM_ART_KIND_NULL;
+	if( idx >= max_idx )
+		return WPN_RANDM_ART_KIND_NULL;
+
+	return( g_wpn_randm_art_trans_tab[idx] );
+}
+
+/***************************************************************
+* RAF μफ饤ǥåѴ
+* wpn_kind_t k : ɶμ
+* return : ǥå
+***************************************************************/
+
+long	trans_wpn_randm_art_kind_to_idx( wpn_randm_art_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_wpn_randm_art_trans_tab )
+			/ sizeof( g_wpn_randm_art_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_wpn_randm_art_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
+/***************************************************************
+* ǥå RAF ɶμѴ
+* long idx : ǥå
+* return : ɶμ
+***************************************************************/
+
+armor_randm_art_kind_t	trans_idx_to_armor_randm_art_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_armor_randm_art_trans_tab )
+			/ sizeof( g_armor_randm_art_trans_tab[0] );
+
+	if( idx < 0 )
+		return ARMOR_RANDM_ART_KIND_NULL;
+	if( idx >= max_idx )
+		return ARMOR_RANDM_ART_KIND_NULL;
+
+	return( g_armor_randm_art_trans_tab[idx] );
+}
+
+/***************************************************************
+* RAF ɶμफ饤ǥåѴ
+* armor_kind_t k : ɶμ
+* return : ǥå
+***************************************************************/
+
+long	trans_armor_randm_art_kind_to_idx( armor_randm_art_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_armor_randm_art_trans_tab )
+			/ sizeof( g_armor_randm_art_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_armor_randm_art_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥåμؤѴơ֥ǿ֤
 * return : ǿ
