@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.116 2008/10/07 02:59:19 bowkenken Exp $
+* $Id: gmain.c,v 1.128 2009/05/12 01:30:40 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -73,13 +73,15 @@ static struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vvh"
+#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:md:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",           no_argument,       NULL, 'G' },
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
+	{ "gnome",         required_argument, NULL, 'N' },
+	{ "set-win-pos",   required_argument, NULL, 'P' },
 	{ "text-mode",     required_argument, NULL, 'T' },
 	{ "sel-graph-dir", required_argument, NULL, 'D' },
 	{ "map-scale",     required_argument, NULL, 'S' },
@@ -106,6 +108,10 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
+	"  -N, --gnome              window manager is GNOME\n"
+	"                             ON or OFF\n"
+	"  -P, --set-win-pos        set window position\n"
+	"                             ON or OFF\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -T, --text-mode=POINT    set TEXT mode:\n"
 	"                             point of font, ON or OFF\n"
@@ -180,6 +186,7 @@ void	init_game( void )
 	init_trap();
 	init_fx();
 	init_spell();
+	init_skill();
 	init_chr();
 	init_town();
 	init_menu();
@@ -188,7 +195,9 @@ void	init_game( void )
 	init_misc_menu();
 	init_main_menu();
 	init_request();
+	init_key_item();
 	init_last_boss();
+	init_ending();
 
 	init_mbr_formation();
 
@@ -281,7 +290,7 @@ void	game_main( void )
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
-		menu_load_bar();
+		menu_load_start();
 
 		party_exit_bar();
 	}
@@ -304,6 +313,7 @@ void	game_over( void )
 		switch( get_key( FALSE ) ){
 		case CASE_EXIT:
 			exit_game( EXIT_SUCCESS );
+			break;
 		}
 	}
 }
@@ -314,12 +324,20 @@ void	game_over( void )
 
 void	ending( void )
 {
+	long	c;
+
 	change_scene( SCENE_N_ENDING );
 
 	while( 1 ){
-		switch( get_key( FALSE ) ){
-		case CASE_EXIT:
-			exit_game( EXIT_SUCCESS );
+		draw_ending();
+
+		c = get_key_no_wait();
+		if( c > 0 ){
+			switch( c ){
+			case CASE_EXIT:
+				exit_game( EXIT_SUCCESS );
+				break;
+			}
 		}
 	}
 }
@@ -341,6 +359,12 @@ void	init_arg( void )
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
 
+	g_flg_win_pos_arg_overwrite = FALSE;
+	g_flg_gnome_arg = TRUE;
+	g_flg_set_win_pos_arg = TRUE;
+	g_flg_gnome = TRUE;
+	g_flg_set_win_pos = TRUE;
+
 	g_flg_text_mode = FALSE;
 	g_text_mode_point = 0;
 
@@ -374,11 +398,11 @@ void	chk_arg( int argc, char **argv )
 {
 	long	len;
 	long	mem_size;
-#if	(!HAVE_GETOPT && !HAVE_GETOPT_LONG)
+#if	!defined( HAVE_GETOPT ) && !defined( HAVE_GETOPT_LONG )
 	long	n = 0;
 	char	*optarg;
 	long	optind = argc;
-#endif	/* (!HAVE_GETOPT && !HAVE_GETOPT_LONG) */
+#endif	/* !defined( HAVE_GETOPT ) && !defined( HAVE_GETOPT_LONG ) */
 
 	if( argv == NULL )
 		return;
@@ -420,6 +444,14 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
+		case 'N':
+			g_flg_win_pos_arg_overwrite = TRUE;
+			chk_opt_flg( optarg, &g_flg_gnome_arg, TRUE );
+			break;
+		case 'P':
+			g_flg_win_pos_arg_overwrite = TRUE;
+			chk_opt_flg( optarg, &g_flg_set_win_pos_arg, TRUE );
+			break;
 		case 'T':
 			if( chk_opt_flg( optarg, &g_flg_text_mode,
 					FALSE ) ){
@@ -602,6 +634,11 @@ void	overwrite_arg()
 		g_flg_clr_key_buf = g_flg_clr_key_buf_arg;
 		g_flg_clr_key_buf_menu = g_flg_clr_key_buf_arg;
 	}
+
+	if( g_flg_win_pos_arg_overwrite ){
+		g_flg_gnome = g_flg_gnome_arg;
+		g_flg_set_win_pos = g_flg_set_win_pos_arg;
+	}
 }
 
 /***************************************************************
@@ -968,7 +1005,7 @@ void	ena_term_unix( void )
 
 	flg_term++;
 
-#if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
+#if	defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H )
 	if( flg_term == 1 ){
 		/* ¤Τ */
 # if	defined( HAVE_TERMIOS_H )
@@ -1014,7 +1051,7 @@ void	ena_term_unix( void )
 		}
 # endif	/* HAVE_TERMIOS_H */
 	}
-#endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
+#endif	/* defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H ) */
 }
 
 /***************************************************************
@@ -1062,7 +1099,7 @@ void	clr_key_wait_unix( void )
 
 void	set_key_wait_vtime( long wait_vtime )
 {
-#if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
+#if	defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H )
 	/* ¤Τ */
 # if	defined( HAVE_TERMIOS_H )
 	struct termios	tbuf;
@@ -1095,7 +1132,7 @@ void	set_key_wait_vtime( long wait_vtime )
 		exit_game( EXIT_FAILURE );
 	}
 # endif
-#endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
+#endif
 }
 
 /***************************************************************
